==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/bg.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календар",
    "%s has published the calendar \"%s\"" : "%s публикува календарът \"%s\"",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Отдалечения сървър не предостави достъп до календара (HTTP {%s} грешка)",
    "Error connecting to remote server" : "Грешка при свързване с отдалечен сървър",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Грешка при извличане на ресурс от отдалечен сървър. Възможно е да е свързано с несъответствие в сертификатите",
    "Error requesting resource on remote server" : "Грешка при извличане на ресурс от отдалечен сървър",
    "Individual" : "Индивидуално",
    "Group" : "Група",
    "Resource" : "Ресурс",
    "Room" : "Стая",
    "Unknown" : "Неясно",
    "Required" : "Препоръчително",
    "Optional" : "По избор",
    "Does not attend" : "Няма да присъства",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Вие сте в неизвестна времева зона ({tz}), ще се върнете към UTC",
    "Please create a calendar first." : "Моля създайте каландар първо.",
    "New event" : "Ново събитие",
    "CalDAV address for clients" : "CalDAV адрес за клиенти",
    "Error saving WebCal-calendar" : "Грешка при запаметяване на WebCal-календар",
    "WebDAV address for subscriptions" : "WebDAV адрес за абонаменти",
    "EMail has been sent." : "Имейлът е изпратен.",
    "There was an issue while sending your EMail." : "Възникна грешка по време на изпращане на писмото ви.",
    "group" : "група",
    "Details" : "Детайли",
    "Attendees" : "Присъстващи",
    "Reminders" : "Напомняне",
    "Repeating" : "Повторение",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, крий това събитие",
    "Confirmed" : "Потвърдено",
    "Tentative" : "Несигурно",
    "Cancelled" : "Отказано",
    "Please add a title!" : "Моля добавете заглавие!",
    "Please select a calendar!" : "Моля изберете календар!",
    "Global" : "Глобално",
    "None" : "Няма",
    "Every day" : "Всеки ден",
    "Every week" : "Всяка седмица",
    "Every month" : "Всеки месец",
    "Every year" : "Всяка година",
    "never" : "никога",
    "after" : "переди",
    "How about getting started by importing some calendars?" : "Какво ще кажете като започнете с внасяне на календари?",
    "At time of event" : "По време на събитието",
    "5 minutes before" : "5 минути преди",
    "10 minutes before" : "10 минути преди ",
    "15 minutes before" : "15 минути преди",
    "30 minutes before" : "30 минути преди ",
    "1 hour before" : "1  час преди ",
    "2 hours before" : "2 часа преди ",
    "Custom" : "Избирателно",
    "Audio" : "Аудио",
    "E Mail" : "Електронна поща",
    "Pop up" : "Изкачащ прозорец",
    "sec" : "секунда",
    "min" : "минимално",
    "hours" : "часове",
    "days" : "дена",
    "week" : "седмица",
    "before" : "преди",
    "start" : "начало",
    "end" : "край",
    "Editing reminders of unknown type not supported." : "Редактиране на напомняния от непознат тип не се поддържа",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Successfully imported" : "Правилно инпортирано",
    "Partially imported, 1 failure" : "Частично въвеждане, 1 грешка",
    "Partially imported, {n} failures" : "Частично въвеждане, {n} грешки",
    "Audio alarm" : "Звуков сигнал",
    "Pop-up" : "Изкачащ прозорец",
    "E-Mail" : "Електронна поща",
    "{type} {time} before the event starts" : "{type} {time} преди началото на събитието",
    "{type} {time} before the event ends" : "{type} {time} преди края на събитието",
    "{type} {time} after the event starts" : "{type} {time} след началото на събитието",
    "{type} {time} after the event ends" : "{type} {time} след края на събитието",
    "{type} at the event's start" : "{type} в началото на събитието",
    "{type} at the event's end" : "{type} в края на събитието",
    "{type} at {time}" : "{type} в {time}",
    "{calendar} shared by {owner}" : "{calendar} споделен от {owner}",
    "Please enter a valid WebCal-URL" : "Моля въведете валиден WebCal адрес",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Тежка грешка в webcal прокси. Моля, свържете се с администратора за повече информация.",
    "Title of the Event" : "Заглавие на събитието",
    "starts" : "започва",
    "ends" : "свършва",
    "All day Event" : "Целодневно събитие",
    "Delete" : "Изтриване",
    "Cancel" : "Отказ",
    "More ..." : "Още...",
    "Create" : "Създаване",
    "Update" : "Обновяване",
    "Close" : "Затвори",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Event status" : "Състояние на събитие",
    "Visibility when sharing" : "Видимост при споделяне",
    "Export" : "Експорт",
    "%s has published the calendar %s" : "%s публикува календарът \"%s\"",
    "Hello," : "Здравей, ",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Искаме да те информираме че %s е публикувал календар {boldstart}%s{boldend}.",
    "Click here to access it" : "Натисни тук за да го достъпиш",
    "Cheers!" : "Поздрави!",
    "We wanted to inform you that %s has published the calendar %s." : "Искаме да те информираме че %s е публикувал календар %s.",
    "Click on the link below to access it" : "Натисни на връзката отдолу за да го достъпиш ",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Поради грешка в по-нови версии, календара не е способен да предостави поддръжка за функционалността поток на активи.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Свържи се с администратора с молба за изключване на \"asset-pipeline.enabled\" конфигурационна опция.",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "Today" : "Днес",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Някои събития в този календар са счупени. Моля погледни JS конзолата за подробности.",
    "Share Calendar" : "Споделяне на Календара",
    "Shared" : "Споделено",
    "More" : "Още",
    "Edit" : "Редакция",
    "Link" : "Връзка",
    "Download" : "Изтегляне",
    "Share with users or groups" : "Споделяне с потребители или групи",
    "can edit" : "може да променя",
    "Share link" : "Сподели връзка",
    "Public access" : "Публичен достъп",
    "Email link to person" : "Имейл връзка към човек",
    "Send" : "Изпрати",
    "New Calendar" : "Нов календар",
    "Name" : "Име",
    "New Subscription" : "Нов абонамент",
    "Go back" : "Назад",
    "Go forward" : "Продължи напред",
    "Edit event" : "Редакция на събитието",
    "Delete Event" : "Изтрий събитие",
    "Save Event" : "Запамети събитие",
    "Time" : "Време",
    "Type" : "Тип",
    "Relative" : "Относителен",
    "Absolute" : "Абослютен",
    "Repeat" : "Да се повтаря",
    "times every" : "на всеки",
    "Add" : "Добави",
    "E-Mail address of attendee" : "Имейл адрес на участник",
    "Please add your email address in the personal settings in order to add attendees." : "Добави e-mail адреса си в личните настройки за да можеш да добавяш участници.",
    "from" : "от",
    "to" : "до",
    "This event's repeating rule is not supported yet." : "Все още няма поддръжка за правило за повторение на това събитие ",
    "Support for advanced rules will be added with subsequent updates." : "Поддръжка за сложни правила ще бъде добавена с идните обновления.",
    "Reset repeating rule" : "Занули правило за повторение",
    "Repeat every ..." : "Повтаряй на всеки ...",
    "end repeat ..." : "приключи повторението ...",
    "times" : "пъти",
    "Import Calendars" : "Внасяне на календари",
    "Import canceled" : "Внасянето прекратено",
    "Analyzing calendar" : "Анализиране на календар",
    "The file contains objects incompatible with the selected calendar" : "Обектите от съдържанието на файла не са съвместими с избрания календар",
    "New calendar" : "Нов календар",
    "File is empty" : "Файлът е празен",
    "Import scheduled" : "Внасянето насрочено",
    "Publish URL" : "Публикувай URL",
    "Iframe to integrate" : "Рамка за вграждане",
    "Settings & import" : "Настройки и внасяне",
    "Skip simple event editor" : "Пропусни опростения редактор за събития",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Import calendar" : "Внасяне на календар",
    "No Calendars selected for import" : "Няма избрани календари за внасяне",
    "Primary CalDAV address" : "Основен CalDAV адрес",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV адрес"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/bg.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календар",
    "%s has published the calendar \"%s\"" : "%s публикува календарът \"%s\"",
    "Too many redirects. Aborting ..." : "Прекалено много пренасочвания. Прекъсване ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Отдалечения сървър не предостави достъп до календара (HTTP {%s} грешка)",
    "Error connecting to remote server" : "Грешка при свързване с отдалечен сървър",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Грешка при извличане на ресурс от отдалечен сървър. Възможно е да е свързано с несъответствие в сертификатите",
    "Error requesting resource on remote server" : "Грешка при извличане на ресурс от отдалечен сървър",
    "Individual" : "Индивидуално",
    "Group" : "Група",
    "Resource" : "Ресурс",
    "Room" : "Стая",
    "Unknown" : "Неясно",
    "Required" : "Препоръчително",
    "Optional" : "По избор",
    "Does not attend" : "Няма да присъства",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Вие сте в неизвестна времева зона ({tz}), ще се върнете към UTC",
    "Please create a calendar first." : "Моля създайте каландар първо.",
    "New event" : "Ново събитие",
    "CalDAV address for clients" : "CalDAV адрес за клиенти",
    "Error saving WebCal-calendar" : "Грешка при запаметяване на WebCal-календар",
    "WebDAV address for subscriptions" : "WebDAV адрес за абонаменти",
    "EMail has been sent." : "Имейлът е изпратен.",
    "There was an issue while sending your EMail." : "Възникна грешка по време на изпращане на писмото ви.",
    "group" : "група",
    "Details" : "Детайли",
    "Attendees" : "Присъстващи",
    "Reminders" : "Напомняне",
    "Repeating" : "Повторение",
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, крий това събитие",
    "Confirmed" : "Потвърдено",
    "Tentative" : "Несигурно",
    "Cancelled" : "Отказано",
    "Please add a title!" : "Моля добавете заглавие!",
    "Please select a calendar!" : "Моля изберете календар!",
    "The event ends before it starts!" : "Събитието приключва преди да е започнало!",
    "Global" : "Глобално",
    "None" : "Няма",
    "Every day" : "Всеки ден",
    "Every week" : "Всяка седмица",
    "Every month" : "Всеки месец",
    "Every year" : "Всяка година",
    "never" : "никога",
    "after" : "переди",
    "How about getting started by importing some calendars?" : "Какво ще кажете като започнете с внасяне на календари?",
    "At time of event" : "По време на събитието",
    "5 minutes before" : "5 минути преди",
    "10 minutes before" : "10 минути преди ",
    "15 minutes before" : "15 минути преди",
    "30 minutes before" : "30 минути преди ",
    "1 hour before" : "1  час преди ",
    "2 hours before" : "2 часа преди ",
    "Custom" : "Избирателно",
    "Audio" : "Аудио",
    "E Mail" : "Електронна поща",
    "Pop up" : "Изкачащ прозорец",
    "sec" : "секунда",
    "min" : "минимално",
    "hours" : "часове",
    "days" : "дена",
    "week" : "седмица",
    "before" : "преди",
    "start" : "начало",
    "end" : "край",
    "Editing reminders of unknown type not supported." : "Редактиране на напомняния от непознат тип не се поддържа",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Successfully imported" : "Правилно инпортирано",
    "Partially imported, 1 failure" : "Частично въвеждане, 1 грешка",
    "Partially imported, {n} failures" : "Частично въвеждане, {n} грешки",
    "Audio alarm" : "Звуков сигнал",
    "Pop-up" : "Изкачащ прозорец",
    "E-Mail" : "Електронна поща",
    "{type} {time} before the event starts" : "{type} {time} преди началото на събитието",
    "{type} {time} before the event ends" : "{type} {time} преди края на събитието",
    "{type} {time} after the event starts" : "{type} {time} след началото на събитието",
    "{type} {time} after the event ends" : "{type} {time} след края на събитието",
    "{type} at the event's start" : "{type} в началото на събитието",
    "{type} at the event's end" : "{type} в края на събитието",
    "{type} at {time}" : "{type} в {time}",
    "{calendar} shared by {owner}" : "{calendar} споделен от {owner}",
    "Please enter a valid WebCal-URL" : "Моля въведете валиден WebCal адрес",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Тежка грешка в webcal прокси. Моля, свържете се с администратора за повече информация.",
    "Title of the Event" : "Заглавие на събитието",
    "Starts" : "Започва",
    "Ends" : "Завършва",
    "All day Event" : "Целодневно събитие",
    "Delete" : "Изтриване",
    "Cancel" : "Отказ",
    "More ..." : "Още...",
    "Create" : "Създаване",
    "Update" : "Обновяване",
    "Close" : "Затвори",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Event status" : "Състояние на събитие",
    "Visibility when sharing" : "Видимост при споделяне",
    "Export" : "Експорт",
    "%s has published the calendar %s" : "%s публикува календарът \"%s\"",
    "Hello," : "Здравей, ",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Искаме да те информираме че %s е публикувал календар {boldstart}%s{boldend}.",
    "Click here to access it" : "Натисни тук за да го достъпиш",
    "Cheers!" : "Поздрави!",
    "We wanted to inform you that %s has published the calendar %s." : "Искаме да те информираме че %s е публикувал календар %s.",
    "Click on the link below to access it" : "Натисни на връзката отдолу за да го достъпиш ",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Поради грешка в по-нови версии, календара не е способен да предостави поддръжка за функционалността поток на активи.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Свържи се с администратора с молба за изключване на \"asset-pipeline.enabled\" конфигурационна опция.",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "Today" : "Днес",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Някои събития в този календар са счупени. Моля погледни JS конзолата за подробности.",
    "Share Calendar" : "Споделяне на Календара",
    "Shared" : "Споделено",
    "More" : "Още",
    "Edit" : "Редакция",
    "Link" : "Връзка",
    "iCal link" : "iCal връзка",
    "Download" : "Изтегляне",
    "Share with users or groups" : "Споделяне с потребители или групи",
    "can edit" : "може да променя",
    "Share link" : "Сподели връзка",
    "Public access" : "Публичен достъп",
    "Email link to person" : "Имейл връзка към човек",
    "Send" : "Изпрати",
    "New Calendar" : "Нов календар",
    "Name" : "Име",
    "New Subscription" : "Нов абонамент",
    "Go back" : "Назад",
    "Go forward" : "Продължи напред",
    "Calendar does not exist" : "Календарът не съществува",
    "Maybe you got a wrong link or the calendar was unshared?" : "Може би имате грешна връзка или календарът не е бил споделен?",
    "Edit event" : "Редакция на събитието",
    "Delete Event" : "Изтрий събитие",
    "Save Event" : "Запамети събитие",
    "Time" : "Време",
    "Type" : "Тип",
    "Relative" : "Относителен",
    "Absolute" : "Абослютен",
    "Repeat" : "Да се повтаря",
    "times every" : "на всеки",
    "Add" : "Добави",
    "E-Mail address of attendee" : "Имейл адрес на участник",
    "Please add your email address in the personal settings in order to add attendees." : "Добави e-mail адреса си в личните настройки за да можеш да добавяш участници.",
    "from" : "от",
    "to" : "до",
    "This event's repeating rule is not supported yet." : "Все още няма поддръжка за правило за повторение на това събитие ",
    "Support for advanced rules will be added with subsequent updates." : "Поддръжка за сложни правила ще бъде добавена с идните обновления.",
    "Reset repeating rule" : "Занули правило за повторение",
    "Repeat every ..." : "Повтаряй на всеки ...",
    "end repeat ..." : "приключи повторението ...",
    "times" : "пъти",
    "Import Calendars" : "Внасяне на календари",
    "Import canceled" : "Внасянето прекратено",
    "Analyzing calendar" : "Анализиране на календар",
    "The file contains objects incompatible with the selected calendar" : "Обектите от съдържанието на файла не са съвместими с избрания календар",
    "New calendar" : "Нов календар",
    "File is empty" : "Файлът е празен",
    "Import scheduled" : "Внасянето насрочено",
    "%s shared the calendar <strong>%s</strong> with you" : "%s сподели календарът <strong>%s</strong> с вас",
    "Embed" : "Вграден",
    "IFrame to integrate" : "Рамка за вграждане",
    "Publish URL" : "Публикувай URL",
    "Settings & import" : "Настройки и внасяне",
    "Skip simple event editor" : "Пропусни опростения редактор за събития",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Import calendar" : "Внасяне на календар",
    "No Calendars selected for import" : "Няма избрани календари за внасяне",
    "Primary CalDAV address" : "Основен CalDAV адрес",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV адрес",
    "Subscribe" : "Абонирай ме"
},
"nplurals=2; plural=(n != 1);");
